A small package to return the count of vowels and consonants.
## How to install

```
pip install vowcon
```

## How to use

Below example will help you

```
from vowcon import vowcon
str1= "Arun"
vowcon.vowels(str1)	# returns the number of vowels in the given string

str1 = "Arun Iyappan"
vowcon.consonants(str1)     #returns the number of consonants in the given string

```
